Documentation
¶
Index ¶
- func DecodeLoginRequest(mux goahttp.Muxer, decoder func(*http.Request) goahttp.Decoder) func(*http.Request) (interface{}, error)
- func EncodeLoginResponse(encoder func(context.Context, http.ResponseWriter) goahttp.Encoder) func(context.Context, http.ResponseWriter, interface{}) error
- func EncodeLogoutResponse(encoder func(context.Context, http.ResponseWriter) goahttp.Encoder) func(context.Context, http.ResponseWriter, interface{}) error
- func LoginAuthPath() string
- func LogoutAuthPath() string
- func Mount(mux goahttp.Muxer, h *Server)
- func MountLoginHandler(mux goahttp.Muxer, h http.Handler)
- func MountLogoutHandler(mux goahttp.Muxer, h http.Handler)
- func NewLoginHandler(endpoint goa.Endpoint, mux goahttp.Muxer, ...) http.Handler
- func NewLoginPayload(body *LoginRequestBody) *auth.LoginPayload
- func NewLogoutHandler(endpoint goa.Endpoint, mux goahttp.Muxer, ...) http.Handler
- func ValidateLoginRequestBody(body *LoginRequestBody) (err error)
- type ErrorNamer
- type LoginRequestBody
- type MountPoint
- type Server
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DecodeLoginRequest ¶
func DecodeLoginRequest(mux goahttp.Muxer, decoder func(*http.Request) goahttp.Decoder) func(*http.Request) (interface{}, error)
DecodeLoginRequest returns a decoder for requests sent to the Auth Login endpoint.
func EncodeLoginResponse ¶
func EncodeLoginResponse(encoder func(context.Context, http.ResponseWriter) goahttp.Encoder) func(context.Context, http.ResponseWriter, interface{}) error
EncodeLoginResponse returns an encoder for responses returned by the Auth Login endpoint.
func EncodeLogoutResponse ¶
func EncodeLogoutResponse(encoder func(context.Context, http.ResponseWriter) goahttp.Encoder) func(context.Context, http.ResponseWriter, interface{}) error
EncodeLogoutResponse returns an encoder for responses returned by the Auth Logout endpoint.
func LoginAuthPath ¶
func LoginAuthPath() string
LoginAuthPath returns the URL path to the Auth service Login HTTP endpoint.
func LogoutAuthPath ¶
func LogoutAuthPath() string
LogoutAuthPath returns the URL path to the Auth service Logout HTTP endpoint.
func MountLoginHandler ¶
MountLoginHandler configures the mux to serve the "Auth" service "Login" endpoint.
func MountLogoutHandler ¶
MountLogoutHandler configures the mux to serve the "Auth" service "Logout" endpoint.
func NewLoginHandler ¶
func NewLoginHandler( endpoint goa.Endpoint, mux goahttp.Muxer, decoder func(*http.Request) goahttp.Decoder, encoder func(context.Context, http.ResponseWriter) goahttp.Encoder, errhandler func(context.Context, http.ResponseWriter, error), formatter func(err error) goahttp.Statuser, ) http.Handler
NewLoginHandler creates a HTTP handler which loads the HTTP request and calls the "Auth" service "Login" endpoint.
func NewLoginPayload ¶
func NewLoginPayload(body *LoginRequestBody) *auth.LoginPayload
NewLoginPayload builds a Auth service Login endpoint payload.
func NewLogoutHandler ¶
func NewLogoutHandler( endpoint goa.Endpoint, mux goahttp.Muxer, decoder func(*http.Request) goahttp.Decoder, encoder func(context.Context, http.ResponseWriter) goahttp.Encoder, errhandler func(context.Context, http.ResponseWriter, error), formatter func(err error) goahttp.Statuser, ) http.Handler
NewLogoutHandler creates a HTTP handler which loads the HTTP request and calls the "Auth" service "Logout" endpoint.
func ValidateLoginRequestBody ¶
func ValidateLoginRequestBody(body *LoginRequestBody) (err error)
ValidateLoginRequestBody runs the validations defined on LoginRequestBody
Types ¶
type ErrorNamer ¶
type ErrorNamer interface {
ErrorName() string
}
ErrorNamer is an interface implemented by generated error structs that exposes the name of the error as defined in the design.
type LoginRequestBody ¶
type LoginRequestBody struct {
// email
Email *string `form:"email,omitempty" json:"email,omitempty" xml:"email,omitempty"`
// password
Password *string `form:"password,omitempty" json:"password,omitempty" xml:"password,omitempty"`
}
LoginRequestBody is the type of the "Auth" service "Login" endpoint HTTP request body.
type MountPoint ¶
type MountPoint struct {
// Method is the name of the service method served by the mounted HTTP handler.
Method string
// Verb is the HTTP method used to match requests to the mounted handler.
Verb string
// Pattern is the HTTP request path pattern used to match requests to the
// mounted handler.
Pattern string
}
MountPoint holds information about the mounted endpoints.
type Server ¶
type Server struct {
Mounts []*MountPoint
Login http.Handler
Logout http.Handler
}
Server lists the Auth service endpoint HTTP handlers.
func New ¶
func New( e *auth.Endpoints, mux goahttp.Muxer, decoder func(*http.Request) goahttp.Decoder, encoder func(context.Context, http.ResponseWriter) goahttp.Encoder, errhandler func(context.Context, http.ResponseWriter, error), formatter func(err error) goahttp.Statuser, ) *Server
New instantiates HTTP handlers for all the Auth service endpoints using the provided encoder and decoder. The handlers are mounted on the given mux using the HTTP verb and path defined in the design. errhandler is called whenever a response fails to be encoded. formatter is used to format errors returned by the service methods prior to encoding. Both errhandler and formatter are optional and can be nil.